@@ -5,6 +5,7 @@ FAKE = False
 
 DEBUG = True
 FULLSCREEN = True
+MOSTRAR_CURSOR = True
 
 NPOINTS = 5
 MISCLICK_THRESHOLD = 30
@@ -20,4 +21,4 @@ DEFAULT_LOCALE = 'en_US'
 RESOURCES_PATH = join(split(__file__)[0], 'resources')
 
 FAST_START = True
-AUTO_CLOSE = True
+AUTO_CLOSE = False
