@@ -33,12 +33,12 @@ class Window(Zaguan):
 
 
 def run_web(fake, device, misclick_threshold, dualclick_threshold,
-            finger_delta, timeout, fast_start, auto_close):
+            finger_delta, timeout, fast_start, auto_close, resources_path):
     controller = CalibratorController(fake, device, misclick_threshold,
                                       dualclick_threshold, finger_delta,
-                                      timeout, fast_start, auto_close)
-    cur_dir = os.path.dirname(os.path.abspath(__file__))
-    file_ = os.path.join(cur_dir, 'web/html/index.html')
+                                      timeout, fast_start, auto_close,
+                                      resources_path)
+    file_ = os.path.join(resources_path, 'theme/index.html')
     uri = 'file://' + urllib.pathname2url(file_)
     zaguan = Window(uri, controller)
     zaguan.run()
